==> huaweicloudsdkeg-3.1.58-py2.py3-none-any.whl: huaweicloudsdkeg/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkeg.v1.eg_client import EgClient
from huaweicloudsdkeg.v1.eg_async_client import EgAsyncClient

from huaweicloudsdkeg.v1.model.agency_create_req import AgencyCreateReq
from huaweicloudsdkeg.v1.model.api_versions_links import ApiVersionsLinks
from huaweicloudsdkeg.v1.model.api_versions_versions import ApiVersionsVersions
from huaweicloudsdkeg.v1.model.batch_window import BatchWindow
from huaweicloudsdkeg.v1.model.catalog_target_info import CatalogTargetInfo
from huaweicloudsdkeg.v1.model.channel_create_req import ChannelCreateReq
from huaweicloudsdkeg.v1.model.channel_info import ChannelInfo
from huaweicloudsdkeg.v1.model.channel_update_req import ChannelUpdateReq
from huaweicloudsdkeg.v1.model.check_put_events_req import CheckPutEventsReq
from huaweicloudsdkeg.v1.model.check_put_events_req_sources import CheckPutEventsReqSources
from huaweicloudsdkeg.v1.model.check_put_events_request import CheckPutEventsRequest
from huaweicloudsdkeg.v1.model.check_put_events_response import CheckPutEventsResponse
from huaweicloudsdkeg.v1.model.check_put_events_result import CheckPutEventsResult
from huaweicloudsdkeg.v1.model.cloud_events import CloudEvents
from huaweicloudsdkeg.v1.model.connection_create_req import ConnectionCreateReq
from huaweicloudsdkeg.v1.model.connection_info import ConnectionInfo
from huaweicloudsdkeg.v1.model.connection_info_flavor import ConnectionInfoFlavor
from huaweicloudsdkeg.v1.model.connection_type import ConnectionType
from huaweicloudsdkeg.v1.model.connection_update_req import ConnectionUpdateReq
from huaweicloudsdkeg.v1.model.create_agencies_request import CreateAgenciesRequest
from huaweicloudsdkeg.v1.model.create_agencies_response import CreateAgenciesResponse
from huaweicloudsdkeg.v1.model.create_channel_request import CreateChannelRequest
from huaweicloudsdkeg.v1.model.create_channel_response import CreateChannelResponse
from huaweicloudsdkeg.v1.model.create_connection_request import CreateConnectionRequest
from huaweicloudsdkeg.v1.model.create_connection_response import CreateConnectionResponse
from huaweicloudsdkeg.v1.model.create_endpoint_request import CreateEndpointRequest
from huaweicloudsdkeg.v1.model.create_endpoint_response import CreateEndpointResponse
from huaweicloudsdkeg.v1.model.create_event_source_request import CreateEventSourceRequest
from huaweicloudsdkeg.v1.model.create_event_source_response import CreateEventSourceResponse
from huaweicloudsdkeg.v1.model.create_event_streaming_request import CreateEventStreamingRequest
from huaweicloudsdkeg.v1.model.create_event_streaming_response import CreateEventStreamingResponse
from huaweicloudsdkeg.v1.model.create_subscription_request import CreateSubscriptionRequest
from huaweicloudsdkeg.v1.model.create_subscription_response import CreateSubscriptionResponse
from huaweicloudsdkeg.v1.model.create_subscription_target_request import CreateSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.create_subscription_target_response import CreateSubscriptionTargetResponse
from huaweicloudsdkeg.v1.model.customize_source_create_req import CustomizeSourceCreateReq
from huaweicloudsdkeg.v1.model.customize_source_info import CustomizeSourceInfo
from huaweicloudsdkeg.v1.model.customize_source_info_event_types import CustomizeSourceInfoEventTypes
from huaweicloudsdkeg.v1.model.customize_source_update_req import CustomizeSourceUpdateReq
from huaweicloudsdkeg.v1.model.dead_letter_queue import DeadLetterQueue
from huaweicloudsdkeg.v1.model.delete_channel_request import DeleteChannelRequest
from huaweicloudsdkeg.v1.model.delete_channel_response import DeleteChannelResponse
from huaweicloudsdkeg.v1.model.delete_connection_request import DeleteConnectionRequest
from huaweicloudsdkeg.v1.model.delete_connection_response import DeleteConnectionResponse
from huaweicloudsdkeg.v1.model.delete_endpoint_request import DeleteEndpointRequest
from huaweicloudsdkeg.v1.model.delete_endpoint_response import DeleteEndpointResponse
from huaweicloudsdkeg.v1.model.delete_event_source_request import DeleteEventSourceRequest
from huaweicloudsdkeg.v1.model.delete_event_source_response import DeleteEventSourceResponse
from huaweicloudsdkeg.v1.model.delete_event_streaming_request import DeleteEventStreamingRequest
from huaweicloudsdkeg.v1.model.delete_event_streaming_response import DeleteEventStreamingResponse
from huaweicloudsdkeg.v1.model.delete_subscription_request import DeleteSubscriptionRequest
from huaweicloudsdkeg.v1.model.delete_subscription_response import DeleteSubscriptionResponse
from huaweicloudsdkeg.v1.model.delete_subscription_target_request import DeleteSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.delete_subscription_target_response import DeleteSubscriptionTargetResponse
from huaweicloudsdkeg.v1.model.deliver_detail import DeliverDetail
from huaweicloudsdkeg.v1.model.deliver_item import DeliverItem
from huaweicloudsdkeg.v1.model.deliver_target import DeliverTarget
from huaweicloudsdkeg.v1.model.detail import Detail
from huaweicloudsdkeg.v1.model.endpoint_connection import EndpointConnection
from huaweicloudsdkeg.v1.model.endpoint_create_req import EndpointCreateReq
from huaweicloudsdkeg.v1.model.endpoint_info import EndpointInfo
from huaweicloudsdkeg.v1.model.endpoint_update_req import EndpointUpdateReq
from huaweicloudsdkeg.v1.model.error_info import ErrorInfo
from huaweicloudsdkeg.v1.model.event_pub_metrics_item import EventPubMetricsItem
from huaweicloudsdkeg.v1.model.event_streaming_create_req import EventStreamingCreateReq
from huaweicloudsdkeg.v1.model.event_streaming_create_req_rule_config import EventStreamingCreateReqRuleConfig
from huaweicloudsdkeg.v1.model.event_streaming_detail import EventStreamingDetail
from huaweicloudsdkeg.v1.model.event_streaming_operate_req import EventStreamingOperateReq
from huaweicloudsdkeg.v1.model.event_streaming_sink import EventStreamingSink
from huaweicloudsdkeg.v1.model.event_streaming_source import EventStreamingSource
from huaweicloudsdkeg.v1.model.event_streaming_update_req import EventStreamingUpdateReq
from huaweicloudsdkeg.v1.model.event_sub_metrics_item import EventSubMetricsItem
from huaweicloudsdkeg.v1.model.header_parameter import HeaderParameter
from huaweicloudsdkeg.v1.model.invocation_http_parameters import InvocationHttpParameters
from huaweicloudsdkeg.v1.model.kafka_connection_detail import KafkaConnectionDetail
from huaweicloudsdkeg.v1.model.kafka_target_detail import KafkaTargetDetail
from huaweicloudsdkeg.v1.model.kafka_target_detail_key_transform import KafkaTargetDetailKeyTransform
from huaweicloudsdkeg.v1.model.list_agencies_request import ListAgenciesRequest
from huaweicloudsdkeg.v1.model.list_agencies_response import ListAgenciesResponse
from huaweicloudsdkeg.v1.model.list_api_versions_request import ListApiVersionsRequest
from huaweicloudsdkeg.v1.model.list_api_versions_response import ListApiVersionsResponse
from huaweicloudsdkeg.v1.model.list_channels_request import ListChannelsRequest
from huaweicloudsdkeg.v1.model.list_channels_response import ListChannelsResponse
from huaweicloudsdkeg.v1.model.list_connections_request import ListConnectionsRequest
from huaweicloudsdkeg.v1.model.list_connections_response import ListConnectionsResponse
from huaweicloudsdkeg.v1.model.list_endpoints_request import ListEndpointsRequest
from huaweicloudsdkeg.v1.model.list_endpoints_response import ListEndpointsResponse
from huaweicloudsdkeg.v1.model.list_event_sources_request import ListEventSourcesRequest
from huaweicloudsdkeg.v1.model.list_event_sources_response import ListEventSourcesResponse
from huaweicloudsdkeg.v1.model.list_event_streaming_request import ListEventStreamingRequest
from huaweicloudsdkeg.v1.model.list_event_streaming_response import ListEventStreamingResponse
from huaweicloudsdkeg.v1.model.list_event_target_request import ListEventTargetRequest
from huaweicloudsdkeg.v1.model.list_event_target_response import ListEventTargetResponse
from huaweicloudsdkeg.v1.model.list_obs_buckets_request import ListObsBucketsRequest
from huaweicloudsdkeg.v1.model.list_obs_buckets_response import ListObsBucketsResponse
from huaweicloudsdkeg.v1.model.list_pub_metrics_request import ListPubMetricsRequest
from huaweicloudsdkeg.v1.model.list_pub_metrics_response import ListPubMetricsResponse
from huaweicloudsdkeg.v1.model.list_quotas_request import ListQuotasRequest
from huaweicloudsdkeg.v1.model.list_quotas_response import ListQuotasResponse
from huaweicloudsdkeg.v1.model.list_sub_metrics_request import ListSubMetricsRequest
from huaweicloudsdkeg.v1.model.list_sub_metrics_response import ListSubMetricsResponse
from huaweicloudsdkeg.v1.model.list_subscriptions_request import ListSubscriptionsRequest
from huaweicloudsdkeg.v1.model.list_subscriptions_response import ListSubscriptionsResponse
from huaweicloudsdkeg.v1.model.list_traced_events_request import ListTracedEventsRequest
from huaweicloudsdkeg.v1.model.list_traced_events_resp_result import ListTracedEventsRespResult
from huaweicloudsdkeg.v1.model.list_traced_events_response import ListTracedEventsResponse
from huaweicloudsdkeg.v1.model.list_triggers_request import ListTriggersRequest
from huaweicloudsdkeg.v1.model.list_triggers_response import ListTriggersResponse
from huaweicloudsdkeg.v1.model.list_workflow_triggers_request import ListWorkflowTriggersRequest
from huaweicloudsdkeg.v1.model.list_workflow_triggers_response import ListWorkflowTriggersResponse
from huaweicloudsdkeg.v1.model.obs_bucket_info import ObsBucketInfo
from huaweicloudsdkeg.v1.model.obs_bucket_info_owner import ObsBucketInfoOwner
from huaweicloudsdkeg.v1.model.operate_subscription_request import OperateSubscriptionRequest
from huaweicloudsdkeg.v1.model.operate_subscription_response import OperateSubscriptionResponse
from huaweicloudsdkeg.v1.model.put_events_req import PutEventsReq
from huaweicloudsdkeg.v1.model.put_events_request import PutEventsRequest
from huaweicloudsdkeg.v1.model.put_events_resp_events import PutEventsRespEvents
from huaweicloudsdkeg.v1.model.put_events_response import PutEventsResponse
from huaweicloudsdkeg.v1.model.put_official_events_request import PutOfficialEventsRequest
from huaweicloudsdkeg.v1.model.put_official_events_response import PutOfficialEventsResponse
from huaweicloudsdkeg.v1.model.quota_item_info import QuotaItemInfo
from huaweicloudsdkeg.v1.model.quota_resource_resp import QuotaResourceResp
from huaweicloudsdkeg.v1.model.resume_event_streaming_request import ResumeEventStreamingRequest
from huaweicloudsdkeg.v1.model.resume_event_streaming_response import ResumeEventStreamingResponse
from huaweicloudsdkeg.v1.model.run_option import RunOption
from huaweicloudsdkeg.v1.model.show_detail_of_channel_request import ShowDetailOfChannelRequest
from huaweicloudsdkeg.v1.model.show_detail_of_channel_response import ShowDetailOfChannelResponse
from huaweicloudsdkeg.v1.model.show_detail_of_connection_request import ShowDetailOfConnectionRequest
from huaweicloudsdkeg.v1.model.show_detail_of_connection_response import ShowDetailOfConnectionResponse
from huaweicloudsdkeg.v1.model.show_detail_of_event_request import ShowDetailOfEventRequest
from huaweicloudsdkeg.v1.model.show_detail_of_event_response import ShowDetailOfEventResponse
from huaweicloudsdkeg.v1.model.show_detail_of_event_source_request import ShowDetailOfEventSourceRequest
from huaweicloudsdkeg.v1.model.show_detail_of_event_source_response import ShowDetailOfEventSourceResponse
from huaweicloudsdkeg.v1.model.show_detail_of_event_trace_request import ShowDetailOfEventTraceRequest
from huaweicloudsdkeg.v1.model.show_detail_of_event_trace_response import ShowDetailOfEventTraceResponse
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_request import ShowDetailOfSubscriptionRequest
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_response import ShowDetailOfSubscriptionResponse
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_target_request import ShowDetailOfSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_target_response import ShowDetailOfSubscriptionTargetResponse
from huaweicloudsdkeg.v1.model.show_event_streaming_request import ShowEventStreamingRequest
from huaweicloudsdkeg.v1.model.show_event_streaming_response import ShowEventStreamingResponse
from huaweicloudsdkeg.v1.model.sink_fg_parameters import SinkFGParameters
from huaweicloudsdkeg.v1.model.smn_target_detail import SmnTargetDetail
from huaweicloudsdkeg.v1.model.smn_target_detail_subject_transform import SmnTargetDetailSubjectTransform
from huaweicloudsdkeg.v1.model.source_kafka_mq_parameters import SourceKafkaMQParameters
from huaweicloudsdkeg.v1.model.subscription_create_req import SubscriptionCreateReq
from huaweicloudsdkeg.v1.model.subscription_info import SubscriptionInfo
from huaweicloudsdkeg.v1.model.subscription_operate_req import SubscriptionOperateReq
from huaweicloudsdkeg.v1.model.subscription_operate_resp_events import SubscriptionOperateRespEvents
from huaweicloudsdkeg.v1.model.subscription_source import SubscriptionSource
from huaweicloudsdkeg.v1.model.subscription_source_info import SubscriptionSourceInfo
from huaweicloudsdkeg.v1.model.subscription_target import SubscriptionTarget
from huaweicloudsdkeg.v1.model.subscription_target_info import SubscriptionTargetInfo
from huaweicloudsdkeg.v1.model.subscription_update_req import SubscriptionUpdateReq
from huaweicloudsdkeg.v1.model.subscription_used_info import SubscriptionUsedInfo
from huaweicloudsdkeg.v1.model.trans_form import TransForm
from huaweicloudsdkeg.v1.model.update_channel_request import UpdateChannelRequest
from huaweicloudsdkeg.v1.model.update_channel_response import UpdateChannelResponse
from huaweicloudsdkeg.v1.model.update_connection_request import UpdateConnectionRequest
from huaweicloudsdkeg.v1.model.update_connection_response import UpdateConnectionResponse
from huaweicloudsdkeg.v1.model.update_endpoint_request import UpdateEndpointRequest
from huaweicloudsdkeg.v1.model.update_endpoint_response import UpdateEndpointResponse
from huaweicloudsdkeg.v1.model.update_event_source_request import UpdateEventSourceRequest
from huaweicloudsdkeg.v1.model.update_event_source_response import UpdateEventSourceResponse
from huaweicloudsdkeg.v1.model.update_event_streaming_request import UpdateEventStreamingRequest
from huaweicloudsdkeg.v1.model.update_event_streaming_response import UpdateEventStreamingResponse
from huaweicloudsdkeg.v1.model.update_subscription_request import UpdateSubscriptionRequest
from huaweicloudsdkeg.v1.model.update_subscription_response import UpdateSubscriptionResponse
from huaweicloudsdkeg.v1.model.update_subscription_source_request import UpdateSubscriptionSourceRequest
from huaweicloudsdkeg.v1.model.update_subscription_source_response import UpdateSubscriptionSourceResponse
from huaweicloudsdkeg.v1.model.update_subscription_target_request import UpdateSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.update_subscription_target_response import UpdateSubscriptionTargetResponse

==> huaweicloudsdkeg-3.1.92-py2.py3-none-any.whl: huaweicloudsdkeg/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkeg.v1.eg_client import EgClient
from huaweicloudsdkeg.v1.eg_async_client import EgAsyncClient

from huaweicloudsdkeg.v1.model.agency_create_req import AgencyCreateReq
from huaweicloudsdkeg.v1.model.api_versions_links import ApiVersionsLinks
from huaweicloudsdkeg.v1.model.api_versions_versions import ApiVersionsVersions
from huaweicloudsdkeg.v1.model.batch_window import BatchWindow
from huaweicloudsdkeg.v1.model.catalog_target_info import CatalogTargetInfo
from huaweicloudsdkeg.v1.model.channel_create_req import ChannelCreateReq
from huaweicloudsdkeg.v1.model.channel_create_req_policy import ChannelCreateReqPolicy
from huaweicloudsdkeg.v1.model.channel_create_req_principal import ChannelCreateReqPrincipal
from huaweicloudsdkeg.v1.model.channel_info import ChannelInfo
from huaweicloudsdkeg.v1.model.channel_update_req import ChannelUpdateReq
from huaweicloudsdkeg.v1.model.check_put_events_req import CheckPutEventsReq
from huaweicloudsdkeg.v1.model.check_put_events_req_sources import CheckPutEventsReqSources
from huaweicloudsdkeg.v1.model.check_put_events_request import CheckPutEventsRequest
from huaweicloudsdkeg.v1.model.check_put_events_response import CheckPutEventsResponse
from huaweicloudsdkeg.v1.model.check_put_events_result import CheckPutEventsResult
from huaweicloudsdkeg.v1.model.cloud_events import CloudEvents
from huaweicloudsdkeg.v1.model.connection_create_req import ConnectionCreateReq
from huaweicloudsdkeg.v1.model.connection_info import ConnectionInfo
from huaweicloudsdkeg.v1.model.connection_info_flavor import ConnectionInfoFlavor
from huaweicloudsdkeg.v1.model.connection_type import ConnectionType
from huaweicloudsdkeg.v1.model.connection_update_req import ConnectionUpdateReq
from huaweicloudsdkeg.v1.model.create_agencies_request import CreateAgenciesRequest
from huaweicloudsdkeg.v1.model.create_agencies_response import CreateAgenciesResponse
from huaweicloudsdkeg.v1.model.create_channel_request import CreateChannelRequest
from huaweicloudsdkeg.v1.model.create_channel_response import CreateChannelResponse
from huaweicloudsdkeg.v1.model.create_connection_request import CreateConnectionRequest
from huaweicloudsdkeg.v1.model.create_connection_response import CreateConnectionResponse
from huaweicloudsdkeg.v1.model.create_endpoint_request import CreateEndpointRequest
from huaweicloudsdkeg.v1.model.create_endpoint_response import CreateEndpointResponse
from huaweicloudsdkeg.v1.model.create_event_source_request import CreateEventSourceRequest
from huaweicloudsdkeg.v1.model.create_event_source_response import CreateEventSourceResponse
from huaweicloudsdkeg.v1.model.create_event_streaming_request import CreateEventStreamingRequest
from huaweicloudsdkeg.v1.model.create_event_streaming_response import CreateEventStreamingResponse
from huaweicloudsdkeg.v1.model.create_subscription_request import CreateSubscriptionRequest
from huaweicloudsdkeg.v1.model.create_subscription_response import CreateSubscriptionResponse
from huaweicloudsdkeg.v1.model.create_subscription_target_request import CreateSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.create_subscription_target_response import CreateSubscriptionTargetResponse
from huaweicloudsdkeg.v1.model.customize_source_create_req import CustomizeSourceCreateReq
from huaweicloudsdkeg.v1.model.customize_source_info import CustomizeSourceInfo
from huaweicloudsdkeg.v1.model.customize_source_info_event_types import CustomizeSourceInfoEventTypes
from huaweicloudsdkeg.v1.model.customize_source_update_req import CustomizeSourceUpdateReq
from huaweicloudsdkeg.v1.model.dead_letter_queue import DeadLetterQueue
from huaweicloudsdkeg.v1.model.delete_channel_request import DeleteChannelRequest
from huaweicloudsdkeg.v1.model.delete_channel_response import DeleteChannelResponse
from huaweicloudsdkeg.v1.model.delete_connection_request import DeleteConnectionRequest
from huaweicloudsdkeg.v1.model.delete_connection_response import DeleteConnectionResponse
from huaweicloudsdkeg.v1.model.delete_endpoint_request import DeleteEndpointRequest
from huaweicloudsdkeg.v1.model.delete_endpoint_response import DeleteEndpointResponse
from huaweicloudsdkeg.v1.model.delete_event_source_request import DeleteEventSourceRequest
from huaweicloudsdkeg.v1.model.delete_event_source_response import DeleteEventSourceResponse
from huaweicloudsdkeg.v1.model.delete_event_streaming_request import DeleteEventStreamingRequest
from huaweicloudsdkeg.v1.model.delete_event_streaming_response import DeleteEventStreamingResponse
from huaweicloudsdkeg.v1.model.delete_subscription_request import DeleteSubscriptionRequest
from huaweicloudsdkeg.v1.model.delete_subscription_response import DeleteSubscriptionResponse
from huaweicloudsdkeg.v1.model.delete_subscription_target_request import DeleteSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.delete_subscription_target_response import DeleteSubscriptionTargetResponse
from huaweicloudsdkeg.v1.model.deliver_detail import DeliverDetail
from huaweicloudsdkeg.v1.model.deliver_item import DeliverItem
from huaweicloudsdkeg.v1.model.deliver_target import DeliverTarget
from huaweicloudsdkeg.v1.model.eg_target_detail import EgTargetDetail
from huaweicloudsdkeg.v1.model.endpoint_connection import EndpointConnection
from huaweicloudsdkeg.v1.model.endpoint_create_req import EndpointCreateReq
from huaweicloudsdkeg.v1.model.endpoint_info import EndpointInfo
from huaweicloudsdkeg.v1.model.endpoint_update_req import EndpointUpdateReq
from huaweicloudsdkeg.v1.model.error_info import ErrorInfo
from huaweicloudsdkeg.v1.model.event_pub_metrics_item import EventPubMetricsItem
from huaweicloudsdkeg.v1.model.event_streaming_create_req import EventStreamingCreateReq
from huaweicloudsdkeg.v1.model.event_streaming_create_req_rule_config import EventStreamingCreateReqRuleConfig
from huaweicloudsdkeg.v1.model.event_streaming_detail import EventStreamingDetail
from huaweicloudsdkeg.v1.model.event_streaming_operate_req import EventStreamingOperateReq
from huaweicloudsdkeg.v1.model.event_streaming_sink import EventStreamingSink
from huaweicloudsdkeg.v1.model.event_streaming_source import EventStreamingSource
from huaweicloudsdkeg.v1.model.event_streaming_update_req import EventStreamingUpdateReq
from huaweicloudsdkeg.v1.model.event_sub_metrics_item import EventSubMetricsItem
from huaweicloudsdkeg.v1.model.kafka_connection_detail import KafkaConnectionDetail
from huaweicloudsdkeg.v1.model.kafka_target_detail import KafkaTargetDetail
from huaweicloudsdkeg.v1.model.kafka_target_detail_key_transform import KafkaTargetDetailKeyTransform
from huaweicloudsdkeg.v1.model.list_agencies_request import ListAgenciesRequest
from huaweicloudsdkeg.v1.model.list_agencies_response import ListAgenciesResponse
from huaweicloudsdkeg.v1.model.list_api_versions_request import ListApiVersionsRequest
from huaweicloudsdkeg.v1.model.list_api_versions_response import ListApiVersionsResponse
from huaweicloudsdkeg.v1.model.list_channels_request import ListChannelsRequest
from huaweicloudsdkeg.v1.model.list_channels_response import ListChannelsResponse
from huaweicloudsdkeg.v1.model.list_connections_request import ListConnectionsRequest
from huaweicloudsdkeg.v1.model.list_connections_response import ListConnectionsResponse
from huaweicloudsdkeg.v1.model.list_endpoints_request import ListEndpointsRequest
from huaweicloudsdkeg.v1.model.list_endpoints_response import ListEndpointsResponse
from huaweicloudsdkeg.v1.model.list_event_sources_request import ListEventSourcesRequest
from huaweicloudsdkeg.v1.model.list_event_sources_response import ListEventSourcesResponse
from huaweicloudsdkeg.v1.model.list_event_streaming_request import ListEventStreamingRequest
from huaweicloudsdkeg.v1.model.list_event_streaming_response import ListEventStreamingResponse
from huaweicloudsdkeg.v1.model.list_event_target_request import ListEventTargetRequest
from huaweicloudsdkeg.v1.model.list_event_target_response import ListEventTargetResponse
from huaweicloudsdkeg.v1.model.list_obs_buckets_request import ListObsBucketsRequest
from huaweicloudsdkeg.v1.model.list_obs_buckets_response import ListObsBucketsResponse
from huaweicloudsdkeg.v1.model.list_pub_metrics_request import ListPubMetricsRequest
from huaweicloudsdkeg.v1.model.list_pub_metrics_response import ListPubMetricsResponse
from huaweicloudsdkeg.v1.model.list_quotas_request import ListQuotasRequest
from huaweicloudsdkeg.v1.model.list_quotas_response import ListQuotasResponse
from huaweicloudsdkeg.v1.model.list_sub_metrics_request import ListSubMetricsRequest
from huaweicloudsdkeg.v1.model.list_sub_metrics_response import ListSubMetricsResponse
from huaweicloudsdkeg.v1.model.list_subscriptions_request import ListSubscriptionsRequest
from huaweicloudsdkeg.v1.model.list_subscriptions_response import ListSubscriptionsResponse
from huaweicloudsdkeg.v1.model.list_traced_events_request import ListTracedEventsRequest
from huaweicloudsdkeg.v1.model.list_traced_events_resp_result import ListTracedEventsRespResult
from huaweicloudsdkeg.v1.model.list_traced_events_response import ListTracedEventsResponse
from huaweicloudsdkeg.v1.model.list_triggers_request import ListTriggersRequest
from huaweicloudsdkeg.v1.model.list_triggers_response import ListTriggersResponse
from huaweicloudsdkeg.v1.model.list_workflow_triggers_request import ListWorkflowTriggersRequest
from huaweicloudsdkeg.v1.model.list_workflow_triggers_response import ListWorkflowTriggersResponse
from huaweicloudsdkeg.v1.model.obs_bucket_info import ObsBucketInfo
from huaweicloudsdkeg.v1.model.obs_bucket_info_owner import ObsBucketInfoOwner
from huaweicloudsdkeg.v1.model.operate_subscription_request import OperateSubscriptionRequest
from huaweicloudsdkeg.v1.model.operate_subscription_response import OperateSubscriptionResponse
from huaweicloudsdkeg.v1.model.put_events_req import PutEventsReq
from huaweicloudsdkeg.v1.model.put_events_request import PutEventsRequest
from huaweicloudsdkeg.v1.model.put_events_resp_events import PutEventsRespEvents
from huaweicloudsdkeg.v1.model.put_events_response import PutEventsResponse
from huaweicloudsdkeg.v1.model.put_official_events_request import PutOfficialEventsRequest
from huaweicloudsdkeg.v1.model.put_official_events_response import PutOfficialEventsResponse
from huaweicloudsdkeg.v1.model.quota_item_info import QuotaItemInfo
from huaweicloudsdkeg.v1.model.quota_resource_resp import QuotaResourceResp
from huaweicloudsdkeg.v1.model.resume_event_streaming_request import ResumeEventStreamingRequest
from huaweicloudsdkeg.v1.model.resume_event_streaming_response import ResumeEventStreamingResponse
from huaweicloudsdkeg.v1.model.run_option import RunOption
from huaweicloudsdkeg.v1.model.show_detail_of_channel_request import ShowDetailOfChannelRequest
from huaweicloudsdkeg.v1.model.show_detail_of_channel_response import ShowDetailOfChannelResponse
from huaweicloudsdkeg.v1.model.show_detail_of_connection_request import ShowDetailOfConnectionRequest
from huaweicloudsdkeg.v1.model.show_detail_of_connection_response import ShowDetailOfConnectionResponse
from huaweicloudsdkeg.v1.model.show_detail_of_event_request import ShowDetailOfEventRequest
from huaweicloudsdkeg.v1.model.show_detail_of_event_response import ShowDetailOfEventResponse
from huaweicloudsdkeg.v1.model.show_detail_of_event_source_request import ShowDetailOfEventSourceRequest
from huaweicloudsdkeg.v1.model.show_detail_of_event_source_response import ShowDetailOfEventSourceResponse
from huaweicloudsdkeg.v1.model.show_detail_of_event_trace_request import ShowDetailOfEventTraceRequest
from huaweicloudsdkeg.v1.model.show_detail_of_event_trace_response import ShowDetailOfEventTraceResponse
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_request import ShowDetailOfSubscriptionRequest
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_response import ShowDetailOfSubscriptionResponse
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_target_request import ShowDetailOfSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.show_detail_of_subscription_target_response import ShowDetailOfSubscriptionTargetResponse
from huaweicloudsdkeg.v1.model.show_event_streaming_request import ShowEventStreamingRequest
from huaweicloudsdkeg.v1.model.show_event_streaming_response import ShowEventStreamingResponse
from huaweicloudsdkeg.v1.model.sink_fg_parameters import SinkFGParameters
from huaweicloudsdkeg.v1.model.sink_kafka_parameters import SinkKafkaParameters
from huaweicloudsdkeg.v1.model.smn_target_detail import SmnTargetDetail
from huaweicloudsdkeg.v1.model.smn_target_detail_subject_transform import SmnTargetDetailSubjectTransform
from huaweicloudsdkeg.v1.model.source_kafka_mq_parameters import SourceKafkaMQParameters
from huaweicloudsdkeg.v1.model.source_mobile_mq_parameters import SourceMobileMQParameters
from huaweicloudsdkeg.v1.model.subscription_create_req import SubscriptionCreateReq
from huaweicloudsdkeg.v1.model.subscription_info import SubscriptionInfo
from huaweicloudsdkeg.v1.model.subscription_operate_req import SubscriptionOperateReq
from huaweicloudsdkeg.v1.model.subscription_operate_resp_events import SubscriptionOperateRespEvents
from huaweicloudsdkeg.v1.model.subscription_source import SubscriptionSource
from huaweicloudsdkeg.v1.model.subscription_source_info import SubscriptionSourceInfo
from huaweicloudsdkeg.v1.model.subscription_target import SubscriptionTarget
from huaweicloudsdkeg.v1.model.subscription_target_info import SubscriptionTargetInfo
from huaweicloudsdkeg.v1.model.subscription_update_req import SubscriptionUpdateReq
from huaweicloudsdkeg.v1.model.subscription_used_info import SubscriptionUsedInfo
from huaweicloudsdkeg.v1.model.trans_form import TransForm
from huaweicloudsdkeg.v1.model.update_channel_request import UpdateChannelRequest
from huaweicloudsdkeg.v1.model.update_channel_response import UpdateChannelResponse
from huaweicloudsdkeg.v1.model.update_connection_request import UpdateConnectionRequest
from huaweicloudsdkeg.v1.model.update_connection_response import UpdateConnectionResponse
from huaweicloudsdkeg.v1.model.update_endpoint_request import UpdateEndpointRequest
from huaweicloudsdkeg.v1.model.update_endpoint_response import UpdateEndpointResponse
from huaweicloudsdkeg.v1.model.update_event_source_request import UpdateEventSourceRequest
from huaweicloudsdkeg.v1.model.update_event_source_response import UpdateEventSourceResponse
from huaweicloudsdkeg.v1.model.update_event_streaming_request import UpdateEventStreamingRequest
from huaweicloudsdkeg.v1.model.update_event_streaming_response import UpdateEventStreamingResponse
from huaweicloudsdkeg.v1.model.update_subscription_request import UpdateSubscriptionRequest
from huaweicloudsdkeg.v1.model.update_subscription_response import UpdateSubscriptionResponse
from huaweicloudsdkeg.v1.model.update_subscription_source_request import UpdateSubscriptionSourceRequest
from huaweicloudsdkeg.v1.model.update_subscription_source_response import UpdateSubscriptionSourceResponse
from huaweicloudsdkeg.v1.model.update_subscription_target_request import UpdateSubscriptionTargetRequest
from huaweicloudsdkeg.v1.model.update_subscription_target_response import UpdateSubscriptionTargetResponse
